@@ -1,3 +1,4 @@
+import decimal
 from dataclasses import dataclass
 from datetime import datetime
 
@@ -6,7 +7,7 @@ from datetime import datetime
 class OrderBudget:
     accountNumber: str
     quantity: int
-    price: int
+    price: decimal
     ticker: str
     instrumentType: str
     quantityType: str
@@ -15,3 +16,4 @@ class OrderBudget:
     operationMaxDate: datetime
     operation: str
     settlement: str
+    activationPrice: decimal = None
