@@ -1,20 +1,27 @@
-from ppi_client.api.constants import MIME_JSON, ACCOUNT_REFRESH_TOKEN, ACCOUNT_LOGIN
+from ppi_client.api.constants import MIME_JSON, ACCOUNT_REFRESH_TOKEN, ACCOUNT_LOGIN, MARKETDATA_HUB, ACCOUNTDATA_HUB
 from ppi_client.ppi_restclient import RestClient
 
 
 class PPIClient(object):
     __access_data = None
     __rest_client = None
-    ws_connection = None
     token = None
     refreshToken = None
     refreshedCant = 0
     __client_id = None
     __client_secret = None
-    __on_connect_handler = None
-    __on_disconnect_handler = None
-    __on_marketdata_handler = None
-    __on_error_handler = None
+
+    ws_connection_marketdata = None
+    __on_connect_handler_marketdata = None
+    __on_disconnect_handler_marketdata = None
+    __on_data_handler_marketdata = None
+    __on_error_handler_marketdata = None
+
+    ws_connection_accountdata = None
+    __on_connect_handler_accountdata = None
+    __on_disconnect_handler_accountdata = None
+    __on_data_handler_accountdata = None
+    __on_error_handler_accountdata = None
 
     def __init__(self, version, sandbox):
         if sandbox:
@@ -28,9 +35,11 @@ class PPIClient(object):
         self.__rest_client.client_key = self.__client_key
         self.__rest_client.authorized_client = self.__authorized_client
 
+        self.ws_connection_marketdata = None
+        self.__ws_isconnected_marketdata = False
 
-        self.ws_connection = None
-        self.__ws_isconnected = False
+        self.ws_connection_accountdata = None
+        self.__ws_isconnected_accountdata = False
 
     def get_rest_client(self):
         return self.__rest_client
@@ -121,28 +130,28 @@ class PPIClient(object):
 
         return res.response
 
-    async def connect_to_websocket(self, onconnect_handler=None, ondisconnect_handler=None, marketdata_handler=None):
-        self.__on_connect_handler = onconnect_handler
-        self.__on_disconnect_handler = ondisconnect_handler
-        self.__on_marketdata_handler = marketdata_handler
+    async def connect_ws_marketdata(self, onconnect_handler=None, ondisconnect_handler=None, marketdata_handler=None):
+        self.__on_connect_handler_marketdata = onconnect_handler
+        self.__on_disconnect_handler_marketdata = ondisconnect_handler
+        self.__on_data_handler_marketdata = marketdata_handler
 
-        if self.ws_connection and self.__ws_isconnected:
-            return self.ws_connection
+        if self.ws_connection_marketdata and self.__ws_isconnected_marketdata:
+            return self.ws_connection_marketdata
         else:
-            conn = await self.__rest_client.connect_to_websocket()
-            self.ws_connection = conn
+            conn = await self.__rest_client.connect_to_websocket(MARKETDATA_HUB)
+            self.ws_connection_marketdata = conn
 
             def on_open():
-                self.__ws_isconnected = True
-                self.__on_connect_handler()
+                self.__ws_isconnected_marketdata = True
+                self.__on_connect_handler_marketdata()
 
             def on_marketdata(msj):
-                self.__on_marketdata_handler(msj[0])
+                self.__on_data_handler_marketdata(msj[0])
 
             def on_close(msg):
-                lambda: print("connection closed" + msg)
-                self.__ws_isconnected = False
-                self.__on_disconnect_handler()
+                lambda: print("connection to marketdata closed" + msg)
+                self.__ws_isconnected_marketdata = False
+                self.__on_disconnect_handler_marketdata()
 
             def on_scheduled_disconnection(msg):
                 print("connection closed by server")
@@ -150,12 +159,52 @@ class PPIClient(object):
                 on_close(msg)
 
             def on_error():
-                lambda data: print(f"An exception was thrown closed: {data.error}")
+                lambda data: print(f"An exception on marketdata was thrown closed: {data.error}")
 
             conn.on_open(on_open)
             conn.on_close(on_close)
             conn.on("marketdata", on_marketdata)
-            conn.on("scheduled-disconnection", on_scheduled_disconnection)
+            conn.on("scheduled-md-disconnection", on_scheduled_disconnection)
+            conn.on_error(on_error)
+
+            conn.start()
+            return conn
+
+    async def connect_ws_accountdata(self, onconnect_handler=None, ondisconnect_handler=None, data_handler=None):
+        self.__on_connect_handler_accountdata = onconnect_handler
+        self.__on_disconnect_handler_accountdata = ondisconnect_handler
+        self.__on_data_handler_accountdata = data_handler
+
+        if self.ws_connection_accountdata and self.__ws_isconnected_account:
+            return self.ws_connection_accountdata
+        else:
+            conn = await self.__rest_client.connect_to_websocket(ACCOUNTDATA_HUB)
+            self.ws_connection_accountdata = conn
+
+            def on_open():
+                self.__ws_isconnected_accountdata = True
+                self.__on_connect_handler_accountdata()
+
+            def on_data(msj):
+                self.__on_data_handler_accountdata(msj[0])
+
+            def on_close(msg):
+                lambda: print("connection to accountdata closed" + msg)
+                self.__ws_isconnected_accountdata = False
+                self.__on_disconnect_handler_accountdata()
+
+            def on_scheduled_disconnection(msg):
+                print("connection to account data closed by server")
+                conn.stop()
+                on_close(msg)
+
+            def on_error():
+                lambda data: print(f"An exception on account was thrown closed: {data.error}")
+
+            conn.on_open(on_open)
+            conn.on_close(on_close)
+            conn.on("account", on_data)
+            conn.on("scheduled-ac-disconnection", on_scheduled_disconnection)
             conn.on_error(on_error)
 
             conn.start()
